@@ -1,35 +1,7 @@
 """
 Utility functions
 """
-import os
-
-from scmdata import df_append
-
-
-def get_env(env_var):
-    """
-    Get environment variable, if it is not set, raise an error
-
-    Parameters
-    ----------
-    env_var : str
-        Environment variable to get
-
-    Returns
-    -------
-    Any
-        Value of the environment variable
-
-    Raises
-    ------
-    ValueError
-        The environment variable is not set i.e. the output of
-        ``os.getenv(env_var) is None``
-    """
-    if env_var not in os.environ:
-        raise ValueError("{} is not set".format(env_var))
-
-    return os.getenv(env_var)
+import scmdata
 
 
 def calculate_quantiles(
@@ -38,12 +10,12 @@ def calculate_quantiles(
     process_over_columns=("run_id", "ensemble_member", "climate_model"),
 ):
     """
-    Calculate quantiles of an :obj:`ScmDataFrame`
+    Calculate quantiles of an :obj:`ScmRun`
 
     Parameters
     ----------
-    scmdf : :obj:`ScmDataFrame`
-        :obj:`ScmDataFrame` containing the data from which to calculate the
+    scmdf : :obj:`ScmRun`
+        :obj:`ScmRun` containing the data from which to calculate the
         quantiles
 
     quantiles : list of float
@@ -55,8 +27,8 @@ def calculate_quantiles(
 
     Returns
     -------
-    :obj:`ScmDataFrame`
-        :obj:`ScmDataFrame` containing the quantiles of interest, processed
+    :obj:`ScmRun`
+        :obj:`ScmRun` containing the quantiles of interest, processed
         over ``process_over_columns``
     """
     out = []
@@ -66,6 +38,6 @@ def calculate_quantiles(
 
         out.append(quantile_df)
 
-    out = df_append(out)
+    out = scmdata.run_append([scmdata.ScmRun(o) for o in out])
 
     return out
